@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9994 2017-05-28 14:47:33Z David $
+# $Id: __init__.py 10057 2017-06-18 15:16:01Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-05-28 22:47:33 +0800 (Sun, 28 May 2017) $
-# $Revision: 9994 $
+# $Date: 2017-06-18 23:16:01 +0800 (Sun, 18 Jun 2017) $
+# $Revision: 10057 $
 
 import os
 import sys
@@ -44,7 +44,7 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
         'account',
         'pinax_theme_bootstrap', 
         'bootstrapform',
-        'social.apps.django_app.default',
+        'social_django',
     )
     
     ADDING_MIDDLEWARE_CLASSES = (
@@ -78,16 +78,16 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
     ]
     
     if enableFacebook:
-        authenticationBackends.append('social.backends.facebook.FacebookOAuth2')
+        authenticationBackends.append('social_core.backends.facebook.FacebookOAuth2')
         
     if enableGoogle:
-        authenticationBackends.append('social.backends.google.GoogleOAuth2')
+        authenticationBackends.append('social_core.backends.google.GoogleOAuth2')
             
     if enableYahoo:
-        authenticationBackends.append('social.backends.yahoo.YahooOpenId')
+        authenticationBackends.append('social_core.backends.yahoo.YahooOpenId')
         
     if enableLive:
-        authenticationBackends.append('social.backends.live.LiveOAuth2')
+        authenticationBackends.append('social_core.backends.live.LiveOAuth2')
 
     authenticationBackends = tuple(authenticationBackends)
     
@@ -106,8 +106,8 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
         "account.context_processors.account",
         "django.core.context_processors.request", 
         "pinax_theme_bootstrap.context_processors.theme",
-        "social.apps.django_app.context_processors.backends",
-        "social.apps.django_app.context_processors.login_redirect",                             
+        "social_django.context_processors.backends",
+        "social_django.context_processors.login_redirect",                             
     )
     
     extendTemplateContextProcessors(settingsDict, 
